# 用途

​		欢迎您来到ChosenData社区，社区提供宏观、行业、财务、舆情、研究报告、公司数据、人力资源、金融市场等数据， 并提供财务金融分析模型，可以广泛运用于量化投资、金融与财务分析、商业尽调、市场分析与监控等领域。如果您正在学习python进行数据分析，社区会成为您很好的学习工具和数据资源。

​		社区的数据主要来源于公开数据，部分数据来自于ChosenData社区的渠道采集和加工，财务金融模型的算法为主流的计算分析模型。我们将不断扩大数据范围，编写更多的计算分析模型，为社区会员服务。您可以登陆了解社区: https://www.chosen-data.com/